@@ -20,7 +20,7 @@ LOG = logging.getLogger(__name__)
 def log_fail_msg(manager, entrypoint, exception):
     LOG.warning('Encountered exception while loading %(module_name)s: '
                 '"%(message)s". Not using %(name)s.',
-                {'module_name': entrypoint.module_name,
+                {'module_name': entrypoint.module,
                  'message': getattr(exception, 'message',
                                     str(exception)),
                  'name': entrypoint.name})
