@@ -31,7 +31,7 @@ from heat.common import exception
 from heat.common.i18n import _
 from heat.common import password_gen
 
-LOG = logging.getLogger('heat.engine.clients.keystoneclient')
+LOG = logging.getLogger(__name__)
 
 AccessKey = collections.namedtuple('AccessKey', ['id', 'access', 'secret'])
 
@@ -58,7 +58,7 @@ class KsClientWrapper(object):
     directly instantiate instances of this class inside resources themselves.
     """
 
-    def __init__(self, context):
+    def __init__(self, context, region_name):
         # If a trust_id is specified in the context, we immediately
         # authenticate so we can populate the context with a trust token
         # otherwise, we delay client authentication until needed to avoid
@@ -75,6 +75,7 @@ class KsClientWrapper(object):
         self._admin_auth = None
         self._domain_admin_auth = None
         self._domain_admin_client = None
+        self._region_name = region_name
 
         self.session = self.context.keystone_session
         self.v3_endpoint = self.context.keystone_v3_endpoint
@@ -123,8 +124,7 @@ class KsClientWrapper(object):
         importutils.import_module('keystonemiddleware.auth_token')
         auth_region = cfg.CONF.keystone_authtoken.region_name
         if not auth_region:
-            auth_region = (self.context.region_name or
-                           cfg.CONF.region_name_for_services)
+            auth_region = self._region_name
         return auth_region
 
     @property
@@ -225,12 +225,13 @@ class KsClientWrapper(object):
                                        token_info['token']['roles']]
             else:
                 role_kw['role_names'] = self.context.roles
+        allow_redelegation = (cfg.CONF.reauthentication_auth_method == 'trusts'
+                              and cfg.CONF.allow_trusts_redelegation)
         try:
-            trust = self.client.trusts.create(trustor_user=trustor_user_id,
-                                              trustee_user=trustee_user_id,
-                                              project=trustor_proj_id,
-                                              impersonation=True,
-                                              **role_kw)
+            trust = self.client.trusts.create(
+                trustor_user=trustor_user_id, trustee_user=trustee_user_id,
+                project=trustor_proj_id, impersonation=True,
+                allow_redelegation=allow_redelegation, **role_kw)
         except ks_exception.NotFound:
             LOG.debug("Failed to find roles %s for user %s"
                       % (role_kw, trustor_user_id))
@@ -330,6 +331,17 @@ class KsClientWrapper(object):
             # FIXME(shardy): Legacy fallback for folks using old heat.conf
             # files which lack domain configuration
             return self.create_stack_user(username=username, password=password)
+        # We are creating automated user, for which most of security
+        # compliance restrictions possibly set in Keystone should not apply,
+        # https://docs.openstack.org/keystone/latest/admin/security-compliance.html
+        # TODO(pas-ha) find a way to deal with password_regex and
+        # disable_user_account_days_inactive
+        # TODO(pas-ha) think if we also need to add lock_password too
+        user_options = {
+            "ignore_change_password_upon_first_use": True,
+            "ignore_password_expiry": True,
+            "ignore_lockout_failure_attempts": True
+        }
         # We add the new user to a special keystone role
         # This role is designed to allow easier differentiation of the
         # heat-generated "stack users" which will generally have credentials
@@ -341,7 +353,8 @@ class KsClientWrapper(object):
             # Create user
             user = self.domain_admin_client.users.create(
                 name=self._get_username(username), password=password,
-                default_project=project_id, domain=self.stack_domain_id)
+                default_project=project_id, domain=self.stack_domain_id,
+                options=user_options)
             # Add to stack user role
             LOG.debug("Adding user %(user)s to role %(role)s",
                       {'user': user.id, 'role': role_id})
@@ -583,9 +596,9 @@ class KeystoneClient(object):
     needs to be initialized.
     """
 
-    def __new__(cls, context):
+    def __new__(cls, context, region_name=None):
         if cfg.CONF.keystone_backend == _default_keystone_backend:
-            return KsClientWrapper(context)
+            return KsClientWrapper(context, region_name)
         else:
             return importutils.import_object(
                 cfg.CONF.keystone_backend,
